
'Generated protocol buffer code.'
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from ....tensorflow.core.framework import types_pb2 as tensorflow_dot_core_dot_framework_dot_types__pb2
DESCRIPTOR = _descriptor.FileDescriptor(name='tensorflow/core/framework/graph_transfer_info.proto', package='tensorflow', syntax='proto3', serialized_options=b'\n\x18org.tensorflow.frameworkB\x16GraphTransferInfoProtoP\x01ZZgithub.com/tensorflow/tensorflow/tensorflow/go/core/framework/graph_transfer_info_go_proto\xf8\x01\x01', create_key=_descriptor._internal_create_key, serialized_pb=b'\n3tensorflow/core/framework/graph_transfer_info.proto\x12\ntensorflow\x1a%tensorflow/core/framework/types.proto">\n\x16GraphTransferNodeInput\x12\x0f\n\x07node_id\x18\x01 \x01(\x05\x12\x13\n\x0boutput_port\x18\x02 \x01(\x05"\x9b\x01\n\x15GraphTransferNodeInfo\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0f\n\x07node_id\x18\x02 \x01(\x05\x12\x11\n\ttype_name\x18\x03 \x01(\t\x12\x11\n\tsoc_op_id\x18\x04 \x01(\x05\x12\x12\n\npadding_id\x18\x05 \x01(\x05\x12\x13\n\x0binput_count\x18\x06 \x01(\x05\x12\x14\n\x0coutput_count\x18\x07 \x01(\x05"}\n\x1aGraphTransferConstNodeInfo\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0f\n\x07node_id\x18\x02 \x01(\x05\x12\r\n\x05shape\x18\x03 \x03(\x03\x12\x0c\n\x04data\x18\x04 \x01(\x0c\x12#\n\x05dtype\x18\x05 \x01(\x0e2\x14.tensorflow.DataType"e\n\x1aGraphTransferNodeInputInfo\x12\x0f\n\x07node_id\x18\x01 \x01(\x05\x126\n\nnode_input\x18\x02 \x03(\x0b2".tensorflow.GraphTransferNodeInput"E\n\x1bGraphTransferNodeOutputInfo\x12\x0f\n\x07node_id\x18\x01 \x01(\x05\x12\x15\n\rmax_byte_size\x18\x02 \x03(\x05"c\n\x1fGraphTransferGraphInputNodeInfo\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05shape\x18\x02 \x03(\x03\x12#\n\x05dtype\x18\x03 \x01(\x0e2\x14.tensorflow.DataType"d\n GraphTransferGraphOutputNodeInfo\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05shape\x18\x02 \x03(\x03\x12#\n\x05dtype\x18\x03 \x01(\x0e2\x14.tensorflow.DataType"\x8d\x04\n\x11GraphTransferInfo\x124\n\tnode_info\x18\x01 \x03(\x0b2!.tensorflow.GraphTransferNodeInfo\x12?\n\x0fconst_node_info\x18\x02 \x03(\x0b2&.tensorflow.GraphTransferConstNodeInfo\x12?\n\x0fnode_input_info\x18\x03 \x03(\x0b2&.tensorflow.GraphTransferNodeInputInfo\x12A\n\x10node_output_info\x18\x04 \x03(\x0b2\'.tensorflow.GraphTransferNodeOutputInfo\x12J\n\x15graph_input_node_info\x18\x05 \x03(\x0b2+.tensorflow.GraphTransferGraphInputNodeInfo\x12L\n\x16graph_output_node_info\x18\x06 \x03(\x0b2,.tensorflow.GraphTransferGraphOutputNodeInfo\x12>\n\x0bdestination\x18\x07 \x01(\x0e2).tensorflow.GraphTransferInfo.Destination"#\n\x0bDestination\x12\x07\n\x03NOP\x10\x00\x12\x0b\n\x07HEXAGON\x10\x01B\x93\x01\n\x18org.tensorflow.frameworkB\x16GraphTransferInfoProtoP\x01ZZgithub.com/tensorflow/tensorflow/tensorflow/go/core/framework/graph_transfer_info_go_proto\xf8\x01\x01b\x06proto3', dependencies=[tensorflow_dot_core_dot_framework_dot_types__pb2.DESCRIPTOR])
_GRAPHTRANSFERINFO_DESTINATION = _descriptor.EnumDescriptor(name='Destination', full_name='tensorflow.GraphTransferInfo.Destination', filename=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key, values=[_descriptor.EnumValueDescriptor(name='NOP', index=0, number=0, serialized_options=None, type=None, create_key=_descriptor._internal_create_key), _descriptor.EnumValueDescriptor(name='HEXAGON', index=1, number=1, serialized_options=None, type=None, create_key=_descriptor._internal_create_key)], containing_type=None, serialized_options=None, serialized_start=1323, serialized_end=1358)
_sym_db.RegisterEnumDescriptor(_GRAPHTRANSFERINFO_DESTINATION)
_GRAPHTRANSFERNODEINPUT = _descriptor.Descriptor(name='GraphTransferNodeInput', full_name='tensorflow.GraphTransferNodeInput', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='node_id', full_name='tensorflow.GraphTransferNodeInput.node_id', index=0, number=1, type=5, cpp_type=1, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='output_port', full_name='tensorflow.GraphTransferNodeInput.output_port', index=1, number=2, type=5, cpp_type=1, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=106, serialized_end=168)
_GRAPHTRANSFERNODEINFO = _descriptor.Descriptor(name='GraphTransferNodeInfo', full_name='tensorflow.GraphTransferNodeInfo', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='name', full_name='tensorflow.GraphTransferNodeInfo.name', index=0, number=1, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='node_id', full_name='tensorflow.GraphTransferNodeInfo.node_id', index=1, number=2, type=5, cpp_type=1, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='type_name', full_name='tensorflow.GraphTransferNodeInfo.type_name', index=2, number=3, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='soc_op_id', full_name='tensorflow.GraphTransferNodeInfo.soc_op_id', index=3, number=4, type=5, cpp_type=1, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='padding_id', full_name='tensorflow.GraphTransferNodeInfo.padding_id', index=4, number=5, type=5, cpp_type=1, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='input_count', full_name='tensorflow.GraphTransferNodeInfo.input_count', index=5, number=6, type=5, cpp_type=1, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='output_count', full_name='tensorflow.GraphTransferNodeInfo.output_count', index=6, number=7, type=5, cpp_type=1, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=171, serialized_end=326)
_GRAPHTRANSFERCONSTNODEINFO = _descriptor.Descriptor(name='GraphTransferConstNodeInfo', full_name='tensorflow.GraphTransferConstNodeInfo', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='name', full_name='tensorflow.GraphTransferConstNodeInfo.name', index=0, number=1, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='node_id', full_name='tensorflow.GraphTransferConstNodeInfo.node_id', index=1, number=2, type=5, cpp_type=1, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='shape', full_name='tensorflow.GraphTransferConstNodeInfo.shape', index=2, number=3, type=3, cpp_type=2, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='data', full_name='tensorflow.GraphTransferConstNodeInfo.data', index=3, number=4, type=12, cpp_type=9, label=1, has_default_value=False, default_value=b'', message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='dtype', full_name='tensorflow.GraphTransferConstNodeInfo.dtype', index=4, number=5, type=14, cpp_type=8, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=328, serialized_end=453)
_GRAPHTRANSFERNODEINPUTINFO = _descriptor.Descriptor(name='GraphTransferNodeInputInfo', full_name='tensorflow.GraphTransferNodeInputInfo', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='node_id', full_name='tensorflow.GraphTransferNodeInputInfo.node_id', index=0, number=1, type=5, cpp_type=1, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='node_input', full_name='tensorflow.GraphTransferNodeInputInfo.node_input', index=1, number=2, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=455, serialized_end=556)
_GRAPHTRANSFERNODEOUTPUTINFO = _descriptor.Descriptor(name='GraphTransferNodeOutputInfo', full_name='tensorflow.GraphTransferNodeOutputInfo', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='node_id', full_name='tensorflow.GraphTransferNodeOutputInfo.node_id', index=0, number=1, type=5, cpp_type=1, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='max_byte_size', full_name='tensorflow.GraphTransferNodeOutputInfo.max_byte_size', index=1, number=2, type=5, cpp_type=1, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=558, serialized_end=627)
_GRAPHTRANSFERGRAPHINPUTNODEINFO = _descriptor.Descriptor(name='GraphTransferGraphInputNodeInfo', full_name='tensorflow.GraphTransferGraphInputNodeInfo', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='name', full_name='tensorflow.GraphTransferGraphInputNodeInfo.name', index=0, number=1, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='shape', full_name='tensorflow.GraphTransferGraphInputNodeInfo.shape', index=1, number=2, type=3, cpp_type=2, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='dtype', full_name='tensorflow.GraphTransferGraphInputNodeInfo.dtype', index=2, number=3, type=14, cpp_type=8, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=629, serialized_end=728)
_GRAPHTRANSFERGRAPHOUTPUTNODEINFO = _descriptor.Descriptor(name='GraphTransferGraphOutputNodeInfo', full_name='tensorflow.GraphTransferGraphOutputNodeInfo', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='name', full_name='tensorflow.GraphTransferGraphOutputNodeInfo.name', index=0, number=1, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='shape', full_name='tensorflow.GraphTransferGraphOutputNodeInfo.shape', index=1, number=2, type=3, cpp_type=2, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='dtype', full_name='tensorflow.GraphTransferGraphOutputNodeInfo.dtype', index=2, number=3, type=14, cpp_type=8, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=730, serialized_end=830)
_GRAPHTRANSFERINFO = _descriptor.Descriptor(name='GraphTransferInfo', full_name='tensorflow.GraphTransferInfo', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='node_info', full_name='tensorflow.GraphTransferInfo.node_info', index=0, number=1, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='const_node_info', full_name='tensorflow.GraphTransferInfo.const_node_info', index=1, number=2, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='node_input_info', full_name='tensorflow.GraphTransferInfo.node_input_info', index=2, number=3, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='node_output_info', full_name='tensorflow.GraphTransferInfo.node_output_info', index=3, number=4, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='graph_input_node_info', full_name='tensorflow.GraphTransferInfo.graph_input_node_info', index=4, number=5, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='graph_output_node_info', full_name='tensorflow.GraphTransferInfo.graph_output_node_info', index=5, number=6, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='destination', full_name='tensorflow.GraphTransferInfo.destination', index=6, number=7, type=14, cpp_type=8, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[_GRAPHTRANSFERINFO_DESTINATION], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=833, serialized_end=1358)
_GRAPHTRANSFERCONSTNODEINFO.fields_by_name['dtype'].enum_type = tensorflow_dot_core_dot_framework_dot_types__pb2._DATATYPE
_GRAPHTRANSFERNODEINPUTINFO.fields_by_name['node_input'].message_type = _GRAPHTRANSFERNODEINPUT
_GRAPHTRANSFERGRAPHINPUTNODEINFO.fields_by_name['dtype'].enum_type = tensorflow_dot_core_dot_framework_dot_types__pb2._DATATYPE
_GRAPHTRANSFERGRAPHOUTPUTNODEINFO.fields_by_name['dtype'].enum_type = tensorflow_dot_core_dot_framework_dot_types__pb2._DATATYPE
_GRAPHTRANSFERINFO.fields_by_name['node_info'].message_type = _GRAPHTRANSFERNODEINFO
_GRAPHTRANSFERINFO.fields_by_name['const_node_info'].message_type = _GRAPHTRANSFERCONSTNODEINFO
_GRAPHTRANSFERINFO.fields_by_name['node_input_info'].message_type = _GRAPHTRANSFERNODEINPUTINFO
_GRAPHTRANSFERINFO.fields_by_name['node_output_info'].message_type = _GRAPHTRANSFERNODEOUTPUTINFO
_GRAPHTRANSFERINFO.fields_by_name['graph_input_node_info'].message_type = _GRAPHTRANSFERGRAPHINPUTNODEINFO
_GRAPHTRANSFERINFO.fields_by_name['graph_output_node_info'].message_type = _GRAPHTRANSFERGRAPHOUTPUTNODEINFO
_GRAPHTRANSFERINFO.fields_by_name['destination'].enum_type = _GRAPHTRANSFERINFO_DESTINATION
_GRAPHTRANSFERINFO_DESTINATION.containing_type = _GRAPHTRANSFERINFO
DESCRIPTOR.message_types_by_name['GraphTransferNodeInput'] = _GRAPHTRANSFERNODEINPUT
DESCRIPTOR.message_types_by_name['GraphTransferNodeInfo'] = _GRAPHTRANSFERNODEINFO
DESCRIPTOR.message_types_by_name['GraphTransferConstNodeInfo'] = _GRAPHTRANSFERCONSTNODEINFO
DESCRIPTOR.message_types_by_name['GraphTransferNodeInputInfo'] = _GRAPHTRANSFERNODEINPUTINFO
DESCRIPTOR.message_types_by_name['GraphTransferNodeOutputInfo'] = _GRAPHTRANSFERNODEOUTPUTINFO
DESCRIPTOR.message_types_by_name['GraphTransferGraphInputNodeInfo'] = _GRAPHTRANSFERGRAPHINPUTNODEINFO
DESCRIPTOR.message_types_by_name['GraphTransferGraphOutputNodeInfo'] = _GRAPHTRANSFERGRAPHOUTPUTNODEINFO
DESCRIPTOR.message_types_by_name['GraphTransferInfo'] = _GRAPHTRANSFERINFO
_sym_db.RegisterFileDescriptor(DESCRIPTOR)
GraphTransferNodeInput = _reflection.GeneratedProtocolMessageType('GraphTransferNodeInput', (_message.Message,), {'DESCRIPTOR': _GRAPHTRANSFERNODEINPUT, '__module__': 'tensorflow.core.framework.graph_transfer_info_pb2'})
_sym_db.RegisterMessage(GraphTransferNodeInput)
GraphTransferNodeInfo = _reflection.GeneratedProtocolMessageType('GraphTransferNodeInfo', (_message.Message,), {'DESCRIPTOR': _GRAPHTRANSFERNODEINFO, '__module__': 'tensorflow.core.framework.graph_transfer_info_pb2'})
_sym_db.RegisterMessage(GraphTransferNodeInfo)
GraphTransferConstNodeInfo = _reflection.GeneratedProtocolMessageType('GraphTransferConstNodeInfo', (_message.Message,), {'DESCRIPTOR': _GRAPHTRANSFERCONSTNODEINFO, '__module__': 'tensorflow.core.framework.graph_transfer_info_pb2'})
_sym_db.RegisterMessage(GraphTransferConstNodeInfo)
GraphTransferNodeInputInfo = _reflection.GeneratedProtocolMessageType('GraphTransferNodeInputInfo', (_message.Message,), {'DESCRIPTOR': _GRAPHTRANSFERNODEINPUTINFO, '__module__': 'tensorflow.core.framework.graph_transfer_info_pb2'})
_sym_db.RegisterMessage(GraphTransferNodeInputInfo)
GraphTransferNodeOutputInfo = _reflection.GeneratedProtocolMessageType('GraphTransferNodeOutputInfo', (_message.Message,), {'DESCRIPTOR': _GRAPHTRANSFERNODEOUTPUTINFO, '__module__': 'tensorflow.core.framework.graph_transfer_info_pb2'})
_sym_db.RegisterMessage(GraphTransferNodeOutputInfo)
GraphTransferGraphInputNodeInfo = _reflection.GeneratedProtocolMessageType('GraphTransferGraphInputNodeInfo', (_message.Message,), {'DESCRIPTOR': _GRAPHTRANSFERGRAPHINPUTNODEINFO, '__module__': 'tensorflow.core.framework.graph_transfer_info_pb2'})
_sym_db.RegisterMessage(GraphTransferGraphInputNodeInfo)
GraphTransferGraphOutputNodeInfo = _reflection.GeneratedProtocolMessageType('GraphTransferGraphOutputNodeInfo', (_message.Message,), {'DESCRIPTOR': _GRAPHTRANSFERGRAPHOUTPUTNODEINFO, '__module__': 'tensorflow.core.framework.graph_transfer_info_pb2'})
_sym_db.RegisterMessage(GraphTransferGraphOutputNodeInfo)
GraphTransferInfo = _reflection.GeneratedProtocolMessageType('GraphTransferInfo', (_message.Message,), {'DESCRIPTOR': _GRAPHTRANSFERINFO, '__module__': 'tensorflow.core.framework.graph_transfer_info_pb2'})
_sym_db.RegisterMessage(GraphTransferInfo)
DESCRIPTOR._options = None



from __future__ import annotations

from . import port
from . import core
from . import io
from . import platform
from . import errors

from typing import Callable, List, Tuple, Optional, TYPE_CHECKING
from multiprocessing.pool import ThreadPool
import collections
import threading

if TYPE_CHECKING:
  from . import file_system
  from . import env

kNumThreads = port.num_schedulable_cpus()

def for_each(first: int, last: int, f: Callable[[int], None]):
  """Run a function in parallel using a ThreadPool, but skip the ThreadPool
  on the iOS platform due to its problems with more than a few threads."""
  if platform.is_iphone_platform():
    for i in range(first, last):
      f(i)
  else:
    num_threads: int = min(kNumThreads, last - first)
    with ThreadPool(num_threads) as threads:
      for i in range(first, last):
        threads.apply(f, args=(i,))


# A globbing pattern can only start with these characters:
kGlobbingChars = "*?[\\"

def is_globbing_pattern(pattern: bytes) -> bool:
  return core.string_view(pattern).find_first_of(kGlobbingChars) != core.StringPiece.npos

def patch_pattern(pattern) -> bytes:
  """Make sure that the first entry in `dirs` during glob expansion does not
  contain a glob pattern. This is to prevent a corner-case bug where
  `<pattern>` would be treated differently than `./<pattern>`."""
  pat = core.string_view(pattern)
  fixed_prefix = pat.substr(0, pat.find_first_of(kGlobbingChars))
  # Patching is needed when there is no directory part in `prefix`
  if io.dirname(fixed_prefix).empty():
    return io.join_path(".", pat)
  # No patching needed
  return pat.bytes()

def all_directory_prefixes(d) -> List[bytes]:
  d = core.string_view(d)
  dirs = []
  patched = patch_pattern(d)
  dir = core.StringPiece(patched)
  # If the pattern ends with a `/` (or `\\` on Windows), we need to strip it
  # otherwise we would have one additional matching step and the result set
  # would be empty.
  is_directory = d[d.size() - 1] == b'/'[0]
  if platform.is_windows_platform():
    is_directory = is_directory or (d[d.size() - 1] == b'\\'[0])
  if is_directory:
    dir = io.dirname(dir)
  while not dir.empty():
    dirs.append(dir.bytes())
    new_dir = io.dirname(dir)
    # io::Dirname("/") returns "/" so we need to break the loop.
    # On Windows, io::Dirname("C:\\") would return "C:\\", so we check for
    # identity of the result instead of checking for dir[0] == `/`.
    if dir.slice() == new_dir.slice():
      break
    dir = new_dir
  # Order the array from parent to ancestor (reverse order).
  dirs = list(reversed(dirs))
  return dirs

def get_first_globbing_entry(dirs: List[bytes]) -> int:
  i = 0
  for d in dirs:
    if is_globbing_pattern(d):
      break
    i += 1
  return i

# Status GetMatchingPaths(FileSystem* fs, Env* env, const string& pattern,
#                         std::vector<string>* results) {
def get_matching_paths(fs: file_system.FileSystem, env: env.Env, pattern) -> Tuple[errors.Status, Optional[List]]:
  # // Check that `fs`, `env` and `results` are non-null.
  # if (fs == nullptr || env == nullptr || results == nullptr) {
  #   return Status(tensorflow::error::INVALID_ARGUMENT,
  #                 "Filesystem calls GetMatchingPaths with nullptr arguments");
  # }
  if fs is None or env is None:
    return errors.InvalidArgument("Filesystem calls GetMatchingPaths with nullptr arguments"), None

  # // By design, we don't match anything on empty pattern
  # results->clear();
  results = []
  # if (pattern.empty()) {
  #   return Status::OK();
  # }
  if len(pattern) <= 0:
    return errors.Status.OK(), results

  # // The pattern can contain globbing characters at multiple levels, e.g.:
  # //
  # //   foo/ba?/baz/f*r
  # //
  # // To match the full pattern, we must match every prefix subpattern and then
  # // operate on the children for each match. Thus, we separate all subpatterns
  # // in the `dirs` vector below.
  # std::vector<std::string> dirs = AllDirectoryPrefixes(pattern);
  dirs = all_directory_prefixes(pattern)

  # // We can have patterns that have several parents where no globbing is being
  # // done, for example, `foo/bar/baz/*`. We don't need to expand the directories
  # // which don't contain the globbing characters.
  # int matching_index = GetFirstGlobbingEntry(dirs);
  matching_index = get_first_globbing_entry(dirs)

  # // If we don't have globbing characters in the pattern then it specifies a
  # // path in the filesystem. We add it to the result set if it exists.
  # if (matching_index == dirs.size()) {
  #   if (fs->FileExists(pattern).ok()) {
  #     results->emplace_back(pattern);
  #   }
  #   return Status::OK();
  # }
  if matching_index == len(dirs):
    if fs.file_exists(pattern).ok():
      results.append(pattern)
    return errors.Status.OK(), results

  # // To expand the globbing, we do a BFS from `dirs[matching_index-1]`.
  # // At every step, we work on a pair `{dir, ix}` such that `dir` is a real
  # // directory, `ix < dirs.size() - 1` and `dirs[ix+1]` is a globbing pattern.
  # // To expand the pattern, we select from all the children of `dir` only those
  # // that match against `dirs[ix+1]`.
  # // If there are more entries in `dirs` after `dirs[ix+1]` this mean we have
  # // more patterns to match. So, we add to the queue only those children that
  # // are also directories, paired with `ix+1`.
  # // If there are no more entries in `dirs`, we return all children as part of
  # // the answer.
  # // Since we can get into a combinatorial explosion issue (e.g., pattern
  # // `/*/*/*`), we process the queue in parallel. Each parallel processing takes
  # // elements from `expand_queue` and adds them to `next_expand_queue`, after
  # // which we swap these two queues (similar to double buffering algorithms).
  # // PRECONDITION: `IsGlobbingPattern(dirs[0]) == false`
  # // PRECONDITION: `matching_index > 0`
  # // INVARIANT: If `{d, ix}` is in queue, then `d` and `dirs[ix]` are at the
  # //            same level in the filesystem tree.
  # // INVARIANT: If `{d, _}` is in queue, then `IsGlobbingPattern(d) == false`.
  # // INVARIANT: If `{d, _}` is in queue, then `d` is a real directory.
  # // INVARIANT: If `{_, ix}` is in queue, then `ix < dirs.size() - 1`.
  # // INVARIANT: If `{_, ix}` is in queue, `IsGlobbingPattern(dirs[ix + 1])`.
  # std::deque<std::pair<string, int>> expand_queue;
  expand_queue = collections.deque()
  # std::deque<std::pair<string, int>> next_expand_queue;
  next_expand_queue = collections.deque()
  # expand_queue.emplace_back(dirs[matching_index - 1], matching_index - 1);
  expand_queue.append((dirs[matching_index - 1], matching_index - 1))
  #
  # // Adding to `result` or `new_expand_queue` need to be protected by mutexes
  # // since there are multiple threads writing to these.
  # mutex result_mutex;
  result_mutex = threading.RLock()
  # mutex queue_mutex;
  queue_mutex = threading.RLock()
  #
  # while (!expand_queue.empty()) {
  while len(expand_queue) > 0:
    # next_expand_queue.clear();
    next_expand_queue.clear()
    #
    # // The work item for every item in `expand_queue`.
    # // pattern, we process them in parallel.
    # auto handle_level = [&fs, &results, &dirs, &expand_queue,
    #                      &next_expand_queue, &result_mutex,
    #                      &queue_mutex](int i) {
    def handle_level(i):
      # // See invariants above, all of these are valid accesses.
      # const auto& queue_item = expand_queue.at(i);
      queue_item = expand_queue[i]
      # const std::string& parent = queue_item.first;
      parent: bytes = queue_item[0]
      # const int index = queue_item.second + 1;
      index: int = queue_item[1] + 1
      # const std::string& match_pattern = dirs[index];
      match_pattern = dirs[index]
      #
      # // Get all children of `parent`. If this fails, return early.
      # std::vector<std::string> children;
      # Status s = fs->GetChildren(parent, &children);
      s, children = fs.get_children(parent)
      # if (s.code() == tensorflow::error::PERMISSION_DENIED) {
      #   return;
      # }
      if errors.is_permission_denied(s):
        return
      #
      # // Also return early if we don't have any children
      # if (children.empty()) {
      #   return;
      # }
      if len(children) <= 0:
        return
      #
      # // Since we can get extremely many children here and on some filesystems
      # // `IsDirectory` is expensive, we process the children in parallel.
      # // We also check that children match the pattern in parallel, for speedup.
      # // We store the status of the match and `IsDirectory` in
      # // `children_status` array, one element for each children.
      # std::vector<Status> children_status(children.size());
      children_status = [errors.Status.OK() for _ in range(len(children))]
      # auto handle_children = [&fs, &match_pattern, &parent, &children,
      #                         &children_status](int j) {
      def handle_children(j: int):
        # const std::string path = io::JoinPath(parent, children[j]);
        path = io.join_path(parent, children[j])
        # if (!fs->Match(path, match_pattern)) {
        if not fs.match(path, match_pattern):
          # children_status[j] =
          #     Status(tensorflow::error::CANCELLED, "Operation not needed");
          children_status[j] = errors.Status(errors.error.CANCELLED, "Operation not needed")
        # } else {
        else:
          # children_status[j] = fs->IsDirectory(path);
          children_status[j] = fs.is_directory(path)
        # }
      # };
      # ForEach(0, children.size(), handle_children);
      for_each(0, len(children), handle_children)
      #
      # // At this point, pairing `children` with `children_status` will tell us
      # // if a children:
      # //   * does not match the pattern
      # //   * matches the pattern and is a directory
      # //   * matches the pattern and is not a directory
      # // We fully ignore the first case.
      # // If we matched the last pattern (`index == dirs.size() - 1`) then all
      # // remaining children get added to the result.
      # // Otherwise, only the directories get added to the next queue.
      # for (size_t j = 0; j < children.size(); j++) {
      for j in range(len(children)):
        # if (children_status[j].code() == tensorflow::error::CANCELLED) {
        #   continue;
        # }
        if children_status[j].code() == errors.error.CANCELLED:
          continue
        #
        # const std::string path = io::JoinPath(parent, children[j]);
        path = io.join_path(parent, children[j])
        # if (index == dirs.size() - 1) {
        if index == len(dirs) - 1:
          # mutex_lock l(result_mutex);
          with result_mutex:
            # results->emplace_back(path);
            results.append(path)
        # } else if (children_status[j].ok()) {
        elif children_status[j].ok():
          # mutex_lock l(queue_mutex);
          with queue_mutex:
            # next_expand_queue.emplace_back(path, index);
            next_expand_queue.append((path, index))
        # }
      # }
    # };
    # ForEach(0, expand_queue.size(), handle_level);
    for_each(0, len(expand_queue), handle_level)
    #
    # // After evaluating one level, swap the "buffers"
    # std::swap(expand_queue, next_expand_queue);
    expand_queue, next_expand_queue = next_expand_queue, expand_queue
  # }
  #
  # return Status::OK();
  return errors.Status.OK(), results
# }






'Generated protocol buffer code.'
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
DESCRIPTOR = _descriptor.FileDescriptor(name='tensorflow/core/protobuf/graph_debug_info.proto', package='tensorflow', syntax='proto3', serialized_options=b'\n\x18org.tensorflow.frameworkB\x14GraphDebugInfoProtosP\x01ZUgithub.com/tensorflow/tensorflow/tensorflow/go/core/protobuf/for_core_protos_go_proto\xf8\x01\x01', create_key=_descriptor._internal_create_key, serialized_pb=b'\n/tensorflow/core/protobuf/graph_debug_info.proto\x12\ntensorflow"\xd5\x02\n\x0eGraphDebugInfo\x12\r\n\x05files\x18\x01 \x03(\t\x126\n\x06traces\x18\x02 \x03(\x0b2&.tensorflow.GraphDebugInfo.TracesEntry\x1aX\n\x0bFileLineCol\x12\x12\n\nfile_index\x18\x01 \x01(\x05\x12\x0c\n\x04line\x18\x02 \x01(\x05\x12\x0b\n\x03col\x18\x03 \x01(\x05\x12\x0c\n\x04func\x18\x04 \x01(\t\x12\x0c\n\x04code\x18\x05 \x01(\t\x1aL\n\nStackTrace\x12>\n\x0efile_line_cols\x18\x01 \x03(\x0b2&.tensorflow.GraphDebugInfo.FileLineCol\x1aT\n\x0bTracesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x124\n\x05value\x18\x02 \x01(\x0b2%.tensorflow.GraphDebugInfo.StackTrace:\x028\x01B\x8c\x01\n\x18org.tensorflow.frameworkB\x14GraphDebugInfoProtosP\x01ZUgithub.com/tensorflow/tensorflow/tensorflow/go/core/protobuf/for_core_protos_go_proto\xf8\x01\x01b\x06proto3')
_GRAPHDEBUGINFO_FILELINECOL = _descriptor.Descriptor(name='FileLineCol', full_name='tensorflow.GraphDebugInfo.FileLineCol', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='file_index', full_name='tensorflow.GraphDebugInfo.FileLineCol.file_index', index=0, number=1, type=5, cpp_type=1, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='line', full_name='tensorflow.GraphDebugInfo.FileLineCol.line', index=1, number=2, type=5, cpp_type=1, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='col', full_name='tensorflow.GraphDebugInfo.FileLineCol.col', index=2, number=3, type=5, cpp_type=1, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='func', full_name='tensorflow.GraphDebugInfo.FileLineCol.func', index=3, number=4, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='code', full_name='tensorflow.GraphDebugInfo.FileLineCol.code', index=4, number=5, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=153, serialized_end=241)
_GRAPHDEBUGINFO_STACKTRACE = _descriptor.Descriptor(name='StackTrace', full_name='tensorflow.GraphDebugInfo.StackTrace', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='file_line_cols', full_name='tensorflow.GraphDebugInfo.StackTrace.file_line_cols', index=0, number=1, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=243, serialized_end=319)
_GRAPHDEBUGINFO_TRACESENTRY = _descriptor.Descriptor(name='TracesEntry', full_name='tensorflow.GraphDebugInfo.TracesEntry', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='key', full_name='tensorflow.GraphDebugInfo.TracesEntry.key', index=0, number=1, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='value', full_name='tensorflow.GraphDebugInfo.TracesEntry.value', index=1, number=2, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=b'8\x01', is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=321, serialized_end=405)
_GRAPHDEBUGINFO = _descriptor.Descriptor(name='GraphDebugInfo', full_name='tensorflow.GraphDebugInfo', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='files', full_name='tensorflow.GraphDebugInfo.files', index=0, number=1, type=9, cpp_type=9, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='traces', full_name='tensorflow.GraphDebugInfo.traces', index=1, number=2, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[_GRAPHDEBUGINFO_FILELINECOL, _GRAPHDEBUGINFO_STACKTRACE, _GRAPHDEBUGINFO_TRACESENTRY], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=64, serialized_end=405)
_GRAPHDEBUGINFO_FILELINECOL.containing_type = _GRAPHDEBUGINFO
_GRAPHDEBUGINFO_STACKTRACE.fields_by_name['file_line_cols'].message_type = _GRAPHDEBUGINFO_FILELINECOL
_GRAPHDEBUGINFO_STACKTRACE.containing_type = _GRAPHDEBUGINFO
_GRAPHDEBUGINFO_TRACESENTRY.fields_by_name['value'].message_type = _GRAPHDEBUGINFO_STACKTRACE
_GRAPHDEBUGINFO_TRACESENTRY.containing_type = _GRAPHDEBUGINFO
_GRAPHDEBUGINFO.fields_by_name['traces'].message_type = _GRAPHDEBUGINFO_TRACESENTRY
DESCRIPTOR.message_types_by_name['GraphDebugInfo'] = _GRAPHDEBUGINFO
_sym_db.RegisterFileDescriptor(DESCRIPTOR)
GraphDebugInfo = _reflection.GeneratedProtocolMessageType('GraphDebugInfo', (_message.Message,), {'FileLineCol': _reflection.GeneratedProtocolMessageType('FileLineCol', (_message.Message,), {'DESCRIPTOR': _GRAPHDEBUGINFO_FILELINECOL, '__module__': 'tensorflow.core.protobuf.graph_debug_info_pb2'}), 'StackTrace': _reflection.GeneratedProtocolMessageType('StackTrace', (_message.Message,), {'DESCRIPTOR': _GRAPHDEBUGINFO_STACKTRACE, '__module__': 'tensorflow.core.protobuf.graph_debug_info_pb2'}), 'TracesEntry': _reflection.GeneratedProtocolMessageType('TracesEntry', (_message.Message,), {'DESCRIPTOR': _GRAPHDEBUGINFO_TRACESENTRY, '__module__': 'tensorflow.core.protobuf.graph_debug_info_pb2'}), 'DESCRIPTOR': _GRAPHDEBUGINFO, '__module__': 'tensorflow.core.protobuf.graph_debug_info_pb2'})
_sym_db.RegisterMessage(GraphDebugInfo)
_sym_db.RegisterMessage(GraphDebugInfo.FileLineCol)
_sym_db.RegisterMessage(GraphDebugInfo.StackTrace)
_sym_db.RegisterMessage(GraphDebugInfo.TracesEntry)
DESCRIPTOR._options = None
_GRAPHDEBUGINFO_TRACESENTRY._options = None




'Generated protocol buffer code.'
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
DESCRIPTOR = _descriptor.FileDescriptor(name='tensorflow/core/profiler/protobuf/xplane.proto', package='tensorflow.profiler', syntax='proto3', serialized_options=b'\xf8\x01\x01', create_key=_descriptor._internal_create_key, serialized_pb=b'\n.tensorflow/core/profiler/protobuf/xplane.proto\x12\x13tensorflow.profiler"j\n\x06XSpace\x12+\n\x06planes\x18\x01 \x03(\x0b2\x1b.tensorflow.profiler.XPlane\x12\x0e\n\x06errors\x18\x02 \x03(\t\x12\x10\n\x08warnings\x18\x03 \x03(\t\x12\x11\n\thostnames\x18\x04 \x03(\t"\xba\x03\n\x06XPlane\x12\n\n\x02id\x18\x01 \x01(\x03\x12\x0c\n\x04name\x18\x02 \x01(\t\x12)\n\x05lines\x18\x03 \x03(\x0b2\x1a.tensorflow.profiler.XLine\x12F\n\x0eevent_metadata\x18\x04 \x03(\x0b2..tensorflow.profiler.XPlane.EventMetadataEntry\x12D\n\rstat_metadata\x18\x05 \x03(\x0b2-.tensorflow.profiler.XPlane.StatMetadataEntry\x12)\n\x05stats\x18\x06 \x03(\x0b2\x1a.tensorflow.profiler.XStat\x1aY\n\x12EventMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\x03\x122\n\x05value\x18\x02 \x01(\x0b2#.tensorflow.profiler.XEventMetadata:\x028\x01\x1aW\n\x11StatMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\x03\x121\n\x05value\x18\x02 \x01(\x0b2".tensorflow.profiler.XStatMetadata:\x028\x01"\xbb\x01\n\x05XLine\x12\n\n\x02id\x18\x01 \x01(\x03\x12\x12\n\ndisplay_id\x18\n \x01(\x03\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x14\n\x0cdisplay_name\x18\x0b \x01(\t\x12\x14\n\x0ctimestamp_ns\x18\x03 \x01(\x03\x12\x13\n\x0bduration_ps\x18\t \x01(\x03\x12+\n\x06events\x18\x04 \x03(\x0b2\x1b.tensorflow.profiler.XEventJ\x04\x08\x05\x10\x06J\x04\x08\x06\x10\x07J\x04\x08\x07\x10\x08J\x04\x08\x08\x10\t"\x95\x01\n\x06XEvent\x12\x13\n\x0bmetadata_id\x18\x01 \x01(\x03\x12\x13\n\toffset_ps\x18\x02 \x01(\x03H\x00\x12\x19\n\x0fnum_occurrences\x18\x05 \x01(\x03H\x00\x12\x13\n\x0bduration_ps\x18\x03 \x01(\x03\x12)\n\x05stats\x18\x04 \x03(\x0b2\x1a.tensorflow.profiler.XStatB\x06\n\x04data"\xad\x01\n\x05XStat\x12\x13\n\x0bmetadata_id\x18\x01 \x01(\x03\x12\x16\n\x0cdouble_value\x18\x02 \x01(\x01H\x00\x12\x16\n\x0cuint64_value\x18\x03 \x01(\x04H\x00\x12\x15\n\x0bint64_value\x18\x04 \x01(\x03H\x00\x12\x13\n\tstr_value\x18\x05 \x01(\tH\x00\x12\x15\n\x0bbytes_value\x18\x06 \x01(\x0cH\x00\x12\x13\n\tref_value\x18\x07 \x01(\x04H\x00B\x07\n\x05value"\x8f\x01\n\x0eXEventMetadata\x12\n\n\x02id\x18\x01 \x01(\x03\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x14\n\x0cdisplay_name\x18\x04 \x01(\t\x12\x10\n\x08metadata\x18\x03 \x01(\x0c\x12)\n\x05stats\x18\x05 \x03(\x0b2\x1a.tensorflow.profiler.XStat\x12\x10\n\x08child_id\x18\x06 \x03(\x03">\n\rXStatMetadata\x12\n\n\x02id\x18\x01 \x01(\x03\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0bdescription\x18\x03 \x01(\tB\x03\xf8\x01\x01b\x06proto3')
_XSPACE = _descriptor.Descriptor(name='XSpace', full_name='tensorflow.profiler.XSpace', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='planes', full_name='tensorflow.profiler.XSpace.planes', index=0, number=1, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='errors', full_name='tensorflow.profiler.XSpace.errors', index=1, number=2, type=9, cpp_type=9, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='warnings', full_name='tensorflow.profiler.XSpace.warnings', index=2, number=3, type=9, cpp_type=9, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='hostnames', full_name='tensorflow.profiler.XSpace.hostnames', index=3, number=4, type=9, cpp_type=9, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=71, serialized_end=177)
_XPLANE_EVENTMETADATAENTRY = _descriptor.Descriptor(name='EventMetadataEntry', full_name='tensorflow.profiler.XPlane.EventMetadataEntry', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='key', full_name='tensorflow.profiler.XPlane.EventMetadataEntry.key', index=0, number=1, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='value', full_name='tensorflow.profiler.XPlane.EventMetadataEntry.value', index=1, number=2, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=b'8\x01', is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=444, serialized_end=533)
_XPLANE_STATMETADATAENTRY = _descriptor.Descriptor(name='StatMetadataEntry', full_name='tensorflow.profiler.XPlane.StatMetadataEntry', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='key', full_name='tensorflow.profiler.XPlane.StatMetadataEntry.key', index=0, number=1, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='value', full_name='tensorflow.profiler.XPlane.StatMetadataEntry.value', index=1, number=2, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=b'8\x01', is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=535, serialized_end=622)
_XPLANE = _descriptor.Descriptor(name='XPlane', full_name='tensorflow.profiler.XPlane', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='id', full_name='tensorflow.profiler.XPlane.id', index=0, number=1, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='name', full_name='tensorflow.profiler.XPlane.name', index=1, number=2, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='lines', full_name='tensorflow.profiler.XPlane.lines', index=2, number=3, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='event_metadata', full_name='tensorflow.profiler.XPlane.event_metadata', index=3, number=4, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='stat_metadata', full_name='tensorflow.profiler.XPlane.stat_metadata', index=4, number=5, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='stats', full_name='tensorflow.profiler.XPlane.stats', index=5, number=6, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[_XPLANE_EVENTMETADATAENTRY, _XPLANE_STATMETADATAENTRY], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=180, serialized_end=622)
_XLINE = _descriptor.Descriptor(name='XLine', full_name='tensorflow.profiler.XLine', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='id', full_name='tensorflow.profiler.XLine.id', index=0, number=1, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='display_id', full_name='tensorflow.profiler.XLine.display_id', index=1, number=10, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='name', full_name='tensorflow.profiler.XLine.name', index=2, number=2, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='display_name', full_name='tensorflow.profiler.XLine.display_name', index=3, number=11, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='timestamp_ns', full_name='tensorflow.profiler.XLine.timestamp_ns', index=4, number=3, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='duration_ps', full_name='tensorflow.profiler.XLine.duration_ps', index=5, number=9, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='events', full_name='tensorflow.profiler.XLine.events', index=6, number=4, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=625, serialized_end=812)
_XEVENT = _descriptor.Descriptor(name='XEvent', full_name='tensorflow.profiler.XEvent', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='metadata_id', full_name='tensorflow.profiler.XEvent.metadata_id', index=0, number=1, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='offset_ps', full_name='tensorflow.profiler.XEvent.offset_ps', index=1, number=2, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='num_occurrences', full_name='tensorflow.profiler.XEvent.num_occurrences', index=2, number=5, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='duration_ps', full_name='tensorflow.profiler.XEvent.duration_ps', index=3, number=3, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='stats', full_name='tensorflow.profiler.XEvent.stats', index=4, number=4, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[_descriptor.OneofDescriptor(name='data', full_name='tensorflow.profiler.XEvent.data', index=0, containing_type=None, create_key=_descriptor._internal_create_key, fields=[])], serialized_start=815, serialized_end=964)
_XSTAT = _descriptor.Descriptor(name='XStat', full_name='tensorflow.profiler.XStat', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='metadata_id', full_name='tensorflow.profiler.XStat.metadata_id', index=0, number=1, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='double_value', full_name='tensorflow.profiler.XStat.double_value', index=1, number=2, type=1, cpp_type=5, label=1, has_default_value=False, default_value=float(0), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='uint64_value', full_name='tensorflow.profiler.XStat.uint64_value', index=2, number=3, type=4, cpp_type=4, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='int64_value', full_name='tensorflow.profiler.XStat.int64_value', index=3, number=4, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='str_value', full_name='tensorflow.profiler.XStat.str_value', index=4, number=5, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='bytes_value', full_name='tensorflow.profiler.XStat.bytes_value', index=5, number=6, type=12, cpp_type=9, label=1, has_default_value=False, default_value=b'', message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='ref_value', full_name='tensorflow.profiler.XStat.ref_value', index=6, number=7, type=4, cpp_type=4, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[_descriptor.OneofDescriptor(name='value', full_name='tensorflow.profiler.XStat.value', index=0, containing_type=None, create_key=_descriptor._internal_create_key, fields=[])], serialized_start=967, serialized_end=1140)
_XEVENTMETADATA = _descriptor.Descriptor(name='XEventMetadata', full_name='tensorflow.profiler.XEventMetadata', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='id', full_name='tensorflow.profiler.XEventMetadata.id', index=0, number=1, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='name', full_name='tensorflow.profiler.XEventMetadata.name', index=1, number=2, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='display_name', full_name='tensorflow.profiler.XEventMetadata.display_name', index=2, number=4, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='metadata', full_name='tensorflow.profiler.XEventMetadata.metadata', index=3, number=3, type=12, cpp_type=9, label=1, has_default_value=False, default_value=b'', message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='stats', full_name='tensorflow.profiler.XEventMetadata.stats', index=4, number=5, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='child_id', full_name='tensorflow.profiler.XEventMetadata.child_id', index=5, number=6, type=3, cpp_type=2, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=1143, serialized_end=1286)
_XSTATMETADATA = _descriptor.Descriptor(name='XStatMetadata', full_name='tensorflow.profiler.XStatMetadata', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='id', full_name='tensorflow.profiler.XStatMetadata.id', index=0, number=1, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='name', full_name='tensorflow.profiler.XStatMetadata.name', index=1, number=2, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='description', full_name='tensorflow.profiler.XStatMetadata.description', index=2, number=3, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=1288, serialized_end=1350)
_XSPACE.fields_by_name['planes'].message_type = _XPLANE
_XPLANE_EVENTMETADATAENTRY.fields_by_name['value'].message_type = _XEVENTMETADATA
_XPLANE_EVENTMETADATAENTRY.containing_type = _XPLANE
_XPLANE_STATMETADATAENTRY.fields_by_name['value'].message_type = _XSTATMETADATA
_XPLANE_STATMETADATAENTRY.containing_type = _XPLANE
_XPLANE.fields_by_name['lines'].message_type = _XLINE
_XPLANE.fields_by_name['event_metadata'].message_type = _XPLANE_EVENTMETADATAENTRY
_XPLANE.fields_by_name['stat_metadata'].message_type = _XPLANE_STATMETADATAENTRY
_XPLANE.fields_by_name['stats'].message_type = _XSTAT
_XLINE.fields_by_name['events'].message_type = _XEVENT
_XEVENT.fields_by_name['stats'].message_type = _XSTAT
_XEVENT.oneofs_by_name['data'].fields.append(_XEVENT.fields_by_name['offset_ps'])
_XEVENT.fields_by_name['offset_ps'].containing_oneof = _XEVENT.oneofs_by_name['data']
_XEVENT.oneofs_by_name['data'].fields.append(_XEVENT.fields_by_name['num_occurrences'])
_XEVENT.fields_by_name['num_occurrences'].containing_oneof = _XEVENT.oneofs_by_name['data']
_XSTAT.oneofs_by_name['value'].fields.append(_XSTAT.fields_by_name['double_value'])
_XSTAT.fields_by_name['double_value'].containing_oneof = _XSTAT.oneofs_by_name['value']
_XSTAT.oneofs_by_name['value'].fields.append(_XSTAT.fields_by_name['uint64_value'])
_XSTAT.fields_by_name['uint64_value'].containing_oneof = _XSTAT.oneofs_by_name['value']
_XSTAT.oneofs_by_name['value'].fields.append(_XSTAT.fields_by_name['int64_value'])
_XSTAT.fields_by_name['int64_value'].containing_oneof = _XSTAT.oneofs_by_name['value']
_XSTAT.oneofs_by_name['value'].fields.append(_XSTAT.fields_by_name['str_value'])
_XSTAT.fields_by_name['str_value'].containing_oneof = _XSTAT.oneofs_by_name['value']
_XSTAT.oneofs_by_name['value'].fields.append(_XSTAT.fields_by_name['bytes_value'])
_XSTAT.fields_by_name['bytes_value'].containing_oneof = _XSTAT.oneofs_by_name['value']
_XSTAT.oneofs_by_name['value'].fields.append(_XSTAT.fields_by_name['ref_value'])
_XSTAT.fields_by_name['ref_value'].containing_oneof = _XSTAT.oneofs_by_name['value']
_XEVENTMETADATA.fields_by_name['stats'].message_type = _XSTAT
DESCRIPTOR.message_types_by_name['XSpace'] = _XSPACE
DESCRIPTOR.message_types_by_name['XPlane'] = _XPLANE
DESCRIPTOR.message_types_by_name['XLine'] = _XLINE
DESCRIPTOR.message_types_by_name['XEvent'] = _XEVENT
DESCRIPTOR.message_types_by_name['XStat'] = _XSTAT
DESCRIPTOR.message_types_by_name['XEventMetadata'] = _XEVENTMETADATA
DESCRIPTOR.message_types_by_name['XStatMetadata'] = _XSTATMETADATA
_sym_db.RegisterFileDescriptor(DESCRIPTOR)
XSpace = _reflection.GeneratedProtocolMessageType('XSpace', (_message.Message,), {'DESCRIPTOR': _XSPACE, '__module__': 'tensorflow.core.profiler.protobuf.xplane_pb2'})
_sym_db.RegisterMessage(XSpace)
XPlane = _reflection.GeneratedProtocolMessageType('XPlane', (_message.Message,), {'EventMetadataEntry': _reflection.GeneratedProtocolMessageType('EventMetadataEntry', (_message.Message,), {'DESCRIPTOR': _XPLANE_EVENTMETADATAENTRY, '__module__': 'tensorflow.core.profiler.protobuf.xplane_pb2'}), 'StatMetadataEntry': _reflection.GeneratedProtocolMessageType('StatMetadataEntry', (_message.Message,), {'DESCRIPTOR': _XPLANE_STATMETADATAENTRY, '__module__': 'tensorflow.core.profiler.protobuf.xplane_pb2'}), 'DESCRIPTOR': _XPLANE, '__module__': 'tensorflow.core.profiler.protobuf.xplane_pb2'})
_sym_db.RegisterMessage(XPlane)
_sym_db.RegisterMessage(XPlane.EventMetadataEntry)
_sym_db.RegisterMessage(XPlane.StatMetadataEntry)
XLine = _reflection.GeneratedProtocolMessageType('XLine', (_message.Message,), {'DESCRIPTOR': _XLINE, '__module__': 'tensorflow.core.profiler.protobuf.xplane_pb2'})
_sym_db.RegisterMessage(XLine)
XEvent = _reflection.GeneratedProtocolMessageType('XEvent', (_message.Message,), {'DESCRIPTOR': _XEVENT, '__module__': 'tensorflow.core.profiler.protobuf.xplane_pb2'})
_sym_db.RegisterMessage(XEvent)
XStat = _reflection.GeneratedProtocolMessageType('XStat', (_message.Message,), {'DESCRIPTOR': _XSTAT, '__module__': 'tensorflow.core.profiler.protobuf.xplane_pb2'})
_sym_db.RegisterMessage(XStat)
XEventMetadata = _reflection.GeneratedProtocolMessageType('XEventMetadata', (_message.Message,), {'DESCRIPTOR': _XEVENTMETADATA, '__module__': 'tensorflow.core.profiler.protobuf.xplane_pb2'})
_sym_db.RegisterMessage(XEventMetadata)
XStatMetadata = _reflection.GeneratedProtocolMessageType('XStatMetadata', (_message.Message,), {'DESCRIPTOR': _XSTATMETADATA, '__module__': 'tensorflow.core.profiler.protobuf.xplane_pb2'})
_sym_db.RegisterMessage(XStatMetadata)
DESCRIPTOR._options = None
_XPLANE_EVENTMETADATAENTRY._options = None
_XPLANE_STATMETADATAENTRY._options = None




'Generated protocol buffer code.'
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from ....tensorflow.core.framework import graph_pb2 as tensorflow_dot_core_dot_framework_dot_graph__pb2
DESCRIPTOR = _descriptor.FileDescriptor(name='tensorflow/python/tpu/tensor_tracer.proto', package='tensorflow', syntax='proto3', serialized_options=None, create_key=_descriptor._internal_create_key, serialized_pb=b'\n)tensorflow/python/tpu/tensor_tracer.proto\x12\ntensorflow\x1a%tensorflow/core/framework/graph.proto"\xfb\x04\n\x12TensorTracerReport\x12A\n\x06config\x18\x01 \x01(\x0b21.tensorflow.TensorTracerReport.TensorTracerConfig\x12&\n\x08graphdef\x18\x02 \x01(\x0b2\x14.tensorflow.GraphDef\x12@\n\ttensordef\x18\x03 \x03(\x0b2-.tensorflow.TensorTracerReport.TensordefEntry\x12\x13\n\x0bfingerprint\x18\x04 \x01(\t\x1a`\n\x0eTensordefEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12=\n\x05value\x18\x02 \x01(\x0b2..tensorflow.TensorTracerReport.TracedTensorDef:\x028\x01\x1a\xc8\x01\n\x12TensorTracerConfig\x12\x0f\n\x07version\x18\x01 \x01(\t\x12\x0e\n\x06device\x18\x02 \x01(\t\x12\x12\n\ntrace_mode\x18\x03 \x01(\t\x12\x11\n\tnum_cores\x18\x04 \x01(\x05\x12\x11\n\tnum_hosts\x18\x05 \x01(\x05\x12\x0f\n\x07submode\x18\x06 \x01(\t\x12\x1a\n\x12num_cores_per_host\x18\x07 \x01(\x05\x12\x16\n\x0eincluded_cores\x18\x08 \x03(\x05\x12\x12\n\nsignatures\x18\t \x03(\t\x1av\n\x0fTracedTensorDef\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x0bcache_index\x18\x02 \x01(\x05\x12\x18\n\x10trace_point_name\x18\x03 \x01(\t\x12\x11\n\tis_traced\x18\x04 \x01(\x08\x12\x13\n\x0bexplanation\x18\x05 \x01(\tb\x06proto3', dependencies=[tensorflow_dot_core_dot_framework_dot_graph__pb2.DESCRIPTOR])
_TENSORTRACERREPORT_TENSORDEFENTRY = _descriptor.Descriptor(name='TensordefEntry', full_name='tensorflow.TensorTracerReport.TensordefEntry', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='key', full_name='tensorflow.TensorTracerReport.TensordefEntry.key', index=0, number=1, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='value', full_name='tensorflow.TensorTracerReport.TensordefEntry.value', index=1, number=2, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=b'8\x01', is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=313, serialized_end=409)
_TENSORTRACERREPORT_TENSORTRACERCONFIG = _descriptor.Descriptor(name='TensorTracerConfig', full_name='tensorflow.TensorTracerReport.TensorTracerConfig', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='version', full_name='tensorflow.TensorTracerReport.TensorTracerConfig.version', index=0, number=1, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='device', full_name='tensorflow.TensorTracerReport.TensorTracerConfig.device', index=1, number=2, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='trace_mode', full_name='tensorflow.TensorTracerReport.TensorTracerConfig.trace_mode', index=2, number=3, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='num_cores', full_name='tensorflow.TensorTracerReport.TensorTracerConfig.num_cores', index=3, number=4, type=5, cpp_type=1, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='num_hosts', full_name='tensorflow.TensorTracerReport.TensorTracerConfig.num_hosts', index=4, number=5, type=5, cpp_type=1, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='submode', full_name='tensorflow.TensorTracerReport.TensorTracerConfig.submode', index=5, number=6, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='num_cores_per_host', full_name='tensorflow.TensorTracerReport.TensorTracerConfig.num_cores_per_host', index=6, number=7, type=5, cpp_type=1, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='included_cores', full_name='tensorflow.TensorTracerReport.TensorTracerConfig.included_cores', index=7, number=8, type=5, cpp_type=1, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='signatures', full_name='tensorflow.TensorTracerReport.TensorTracerConfig.signatures', index=8, number=9, type=9, cpp_type=9, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=412, serialized_end=612)
_TENSORTRACERREPORT_TRACEDTENSORDEF = _descriptor.Descriptor(name='TracedTensorDef', full_name='tensorflow.TensorTracerReport.TracedTensorDef', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='name', full_name='tensorflow.TensorTracerReport.TracedTensorDef.name', index=0, number=1, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='cache_index', full_name='tensorflow.TensorTracerReport.TracedTensorDef.cache_index', index=1, number=2, type=5, cpp_type=1, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='trace_point_name', full_name='tensorflow.TensorTracerReport.TracedTensorDef.trace_point_name', index=2, number=3, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='is_traced', full_name='tensorflow.TensorTracerReport.TracedTensorDef.is_traced', index=3, number=4, type=8, cpp_type=7, label=1, has_default_value=False, default_value=False, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='explanation', full_name='tensorflow.TensorTracerReport.TracedTensorDef.explanation', index=4, number=5, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=614, serialized_end=732)
_TENSORTRACERREPORT = _descriptor.Descriptor(name='TensorTracerReport', full_name='tensorflow.TensorTracerReport', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='config', full_name='tensorflow.TensorTracerReport.config', index=0, number=1, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='graphdef', full_name='tensorflow.TensorTracerReport.graphdef', index=1, number=2, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='tensordef', full_name='tensorflow.TensorTracerReport.tensordef', index=2, number=3, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='fingerprint', full_name='tensorflow.TensorTracerReport.fingerprint', index=3, number=4, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[_TENSORTRACERREPORT_TENSORDEFENTRY, _TENSORTRACERREPORT_TENSORTRACERCONFIG, _TENSORTRACERREPORT_TRACEDTENSORDEF], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=97, serialized_end=732)
_TENSORTRACERREPORT_TENSORDEFENTRY.fields_by_name['value'].message_type = _TENSORTRACERREPORT_TRACEDTENSORDEF
_TENSORTRACERREPORT_TENSORDEFENTRY.containing_type = _TENSORTRACERREPORT
_TENSORTRACERREPORT_TENSORTRACERCONFIG.containing_type = _TENSORTRACERREPORT
_TENSORTRACERREPORT_TRACEDTENSORDEF.containing_type = _TENSORTRACERREPORT
_TENSORTRACERREPORT.fields_by_name['config'].message_type = _TENSORTRACERREPORT_TENSORTRACERCONFIG
_TENSORTRACERREPORT.fields_by_name['graphdef'].message_type = tensorflow_dot_core_dot_framework_dot_graph__pb2._GRAPHDEF
_TENSORTRACERREPORT.fields_by_name['tensordef'].message_type = _TENSORTRACERREPORT_TENSORDEFENTRY
DESCRIPTOR.message_types_by_name['TensorTracerReport'] = _TENSORTRACERREPORT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)
TensorTracerReport = _reflection.GeneratedProtocolMessageType('TensorTracerReport', (_message.Message,), {'TensordefEntry': _reflection.GeneratedProtocolMessageType('TensordefEntry', (_message.Message,), {'DESCRIPTOR': _TENSORTRACERREPORT_TENSORDEFENTRY, '__module__': 'tensorflow.python.tpu.tensor_tracer_pb2'}), 'TensorTracerConfig': _reflection.GeneratedProtocolMessageType('TensorTracerConfig', (_message.Message,), {'DESCRIPTOR': _TENSORTRACERREPORT_TENSORTRACERCONFIG, '__module__': 'tensorflow.python.tpu.tensor_tracer_pb2'}), 'TracedTensorDef': _reflection.GeneratedProtocolMessageType('TracedTensorDef', (_message.Message,), {'DESCRIPTOR': _TENSORTRACERREPORT_TRACEDTENSORDEF, '__module__': 'tensorflow.python.tpu.tensor_tracer_pb2'}), 'DESCRIPTOR': _TENSORTRACERREPORT, '__module__': 'tensorflow.python.tpu.tensor_tracer_pb2'})
_sym_db.RegisterMessage(TensorTracerReport)
_sym_db.RegisterMessage(TensorTracerReport.TensordefEntry)
_sym_db.RegisterMessage(TensorTracerReport.TensorTracerConfig)
_sym_db.RegisterMessage(TensorTracerReport.TracedTensorDef)
_TENSORTRACERREPORT_TENSORDEFENTRY._options = None



# -*- coding: utf-8 -*-
from setuptools import setup
import os

def path(to):
  return os.path.join(os.path.dirname(__file__), to)

exec(compile(open(path("setup_info.py")).read(), path("setup_info.py"), "exec"))

packages = \
['tensorflow_checkpoint_reader',
 'tensorflow_checkpoint_reader.pb',
 'tensorflow_checkpoint_reader.pb.tensorflow.compiler.jit',
 'tensorflow_checkpoint_reader.pb.tensorflow.compiler.mlir.lite.quantization',
 'tensorflow_checkpoint_reader.pb.tensorflow.compiler.tf2tensorrt.utils',
 'tensorflow_checkpoint_reader.pb.tensorflow.compiler.tf2xla',
 'tensorflow_checkpoint_reader.pb.tensorflow.compiler.xla',
 'tensorflow_checkpoint_reader.pb.tensorflow.compiler.xla.pjrt.distributed',
 'tensorflow_checkpoint_reader.pb.tensorflow.compiler.xla.python.tpu_driver',
 'tensorflow_checkpoint_reader.pb.tensorflow.compiler.xla.rpc',
 'tensorflow_checkpoint_reader.pb.tensorflow.compiler.xla.service',
 'tensorflow_checkpoint_reader.pb.tensorflow.compiler.xla.service.gpu',
 'tensorflow_checkpoint_reader.pb.tensorflow.compiler.xrt',
 'tensorflow_checkpoint_reader.pb.tensorflow.core.data',
 'tensorflow_checkpoint_reader.pb.tensorflow.core.data.service',
 'tensorflow_checkpoint_reader.pb.tensorflow.core.debug',
 'tensorflow_checkpoint_reader.pb.tensorflow.core.example',
 'tensorflow_checkpoint_reader.pb.tensorflow.core.framework',
 'tensorflow_checkpoint_reader.pb.tensorflow.core.grappler.costs',
 'tensorflow_checkpoint_reader.pb.tensorflow.core.grappler.optimizers.inference',
 'tensorflow_checkpoint_reader.pb.tensorflow.core.kernels.boosted_trees',
 'tensorflow_checkpoint_reader.pb.tensorflow.core.lib.core',
 'tensorflow_checkpoint_reader.pb.tensorflow.core.profiler',
 'tensorflow_checkpoint_reader.pb.tensorflow.core.profiler.protobuf',
 'tensorflow_checkpoint_reader.pb.tensorflow.core.protobuf',
 'tensorflow_checkpoint_reader.pb.tensorflow.core.protobuf.tpu',
 'tensorflow_checkpoint_reader.pb.tensorflow.core.tpu.kernels',
 'tensorflow_checkpoint_reader.pb.tensorflow.core.util',
 'tensorflow_checkpoint_reader.pb.tensorflow.lite.experimental.acceleration.configuration',
 'tensorflow_checkpoint_reader.pb.tensorflow.lite.python.metrics_wrapper',
 'tensorflow_checkpoint_reader.pb.tensorflow.lite.toco',
 'tensorflow_checkpoint_reader.pb.tensorflow.lite.toco.logging',
 'tensorflow_checkpoint_reader.pb.tensorflow.lite.tools.evaluation.proto',
 'tensorflow_checkpoint_reader.pb.tensorflow.python.framework',
 'tensorflow_checkpoint_reader.pb.tensorflow.python.keras.protobuf',
 'tensorflow_checkpoint_reader.pb.tensorflow.python.kernel_tests.proto',
 'tensorflow_checkpoint_reader.pb.tensorflow.python.tpu',
 'tensorflow_checkpoint_reader.pb.tensorflow.python.training',
 'tensorflow_checkpoint_reader.pb.tensorflow.python.util.protobuf',
 'tensorflow_checkpoint_reader.pb.tensorflow.stream_executor',
 'tensorflow_checkpoint_reader.pb.tensorflow.tools.api.lib',
 'tensorflow_checkpoint_reader.pb.tensorflow.tools.proto_text',
 'tensorflow_checkpoint_reader.std',
 'tensorflow_checkpoint_reader.tensorflow',
 'tensorflow_checkpoint_reader.tensorflow.core',
 'tensorflow_checkpoint_reader.tensorflow.core.lib',
 'tensorflow_checkpoint_reader.tensorflow.core.lib.io',
 'tensorflow_checkpoint_reader.tensorflow.python',
 'tensorflow_checkpoint_reader.tensorflow.python.eager',
 'tensorflow_checkpoint_reader.tensorflow.python.framework',
 'tensorflow_checkpoint_reader.tensorflow.python.lib',
 'tensorflow_checkpoint_reader.tensorflow.python.lib.core',
 'tensorflow_checkpoint_reader.tensorflow.python.lib.io',
 'tensorflow_checkpoint_reader.tensorflow.python.platform',
 'tensorflow_checkpoint_reader.tensorflow.python.training',
 'tensorflow_checkpoint_reader.tensorflow.python.util',
 'tensorflow_checkpoint_reader.tensorflow.tools',
 'tensorflow_checkpoint_reader.tensorflow.tools.docs']

package_data = \
{'': ['*']}

install_requires = \
['protobuf<3.19']


setup_kwargs = {
    'package_dir': package_dir,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.6,<4.0',
    **(globals().get('base_kwargs')),
}


setup(**setup_kwargs)




'Generated protocol buffer code.'
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from ....tensorflow.core.framework import tensor_pb2 as tensorflow_dot_core_dot_framework_dot_tensor__pb2
from ....tensorflow.core.framework import tensor_shape_pb2 as tensorflow_dot_core_dot_framework_dot_tensor__shape__pb2
from ....tensorflow.core.framework import types_pb2 as tensorflow_dot_core_dot_framework_dot_types__pb2
DESCRIPTOR = _descriptor.FileDescriptor(name='tensorflow/core/framework/attr_value.proto', package='tensorflow', syntax='proto3', serialized_options=b'\n\x18org.tensorflow.frameworkB\x0fAttrValueProtosP\x01ZQgithub.com/tensorflow/tensorflow/tensorflow/go/core/framework/attr_value_go_proto\xf8\x01\x01', create_key=_descriptor._internal_create_key, serialized_pb=b'\n*tensorflow/core/framework/attr_value.proto\x12\ntensorflow\x1a&tensorflow/core/framework/tensor.proto\x1a,tensorflow/core/framework/tensor_shape.proto\x1a%tensorflow/core/framework/types.proto"\xa6\x04\n\tAttrValue\x12\x0b\n\x01s\x18\x02 \x01(\x0cH\x00\x12\x0b\n\x01i\x18\x03 \x01(\x03H\x00\x12\x0b\n\x01f\x18\x04 \x01(\x02H\x00\x12\x0b\n\x01b\x18\x05 \x01(\x08H\x00\x12$\n\x04type\x18\x06 \x01(\x0e2\x14.tensorflow.DataTypeH\x00\x12-\n\x05shape\x18\x07 \x01(\x0b2\x1c.tensorflow.TensorShapeProtoH\x00\x12)\n\x06tensor\x18\x08 \x01(\x0b2\x17.tensorflow.TensorProtoH\x00\x12/\n\x04list\x18\x01 \x01(\x0b2\x1f.tensorflow.AttrValue.ListValueH\x00\x12(\n\x04func\x18\n \x01(\x0b2\x18.tensorflow.NameAttrListH\x00\x12\x15\n\x0bplaceholder\x18\t \x01(\tH\x00\x1a\xe9\x01\n\tListValue\x12\t\n\x01s\x18\x02 \x03(\x0c\x12\r\n\x01i\x18\x03 \x03(\x03B\x02\x10\x01\x12\r\n\x01f\x18\x04 \x03(\x02B\x02\x10\x01\x12\r\n\x01b\x18\x05 \x03(\x08B\x02\x10\x01\x12&\n\x04type\x18\x06 \x03(\x0e2\x14.tensorflow.DataTypeB\x02\x10\x01\x12+\n\x05shape\x18\x07 \x03(\x0b2\x1c.tensorflow.TensorShapeProto\x12\'\n\x06tensor\x18\x08 \x03(\x0b2\x17.tensorflow.TensorProto\x12&\n\x04func\x18\t \x03(\x0b2\x18.tensorflow.NameAttrListB\x07\n\x05value"\x92\x01\n\x0cNameAttrList\x12\x0c\n\x04name\x18\x01 \x01(\t\x120\n\x04attr\x18\x02 \x03(\x0b2".tensorflow.NameAttrList.AttrEntry\x1aB\n\tAttrEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12$\n\x05value\x18\x02 \x01(\x0b2\x15.tensorflow.AttrValue:\x028\x01B\x83\x01\n\x18org.tensorflow.frameworkB\x0fAttrValueProtosP\x01ZQgithub.com/tensorflow/tensorflow/tensorflow/go/core/framework/attr_value_go_proto\xf8\x01\x01b\x06proto3', dependencies=[tensorflow_dot_core_dot_framework_dot_tensor__pb2.DESCRIPTOR, tensorflow_dot_core_dot_framework_dot_tensor__shape__pb2.DESCRIPTOR, tensorflow_dot_core_dot_framework_dot_types__pb2.DESCRIPTOR])
_ATTRVALUE_LISTVALUE = _descriptor.Descriptor(name='ListValue', full_name='tensorflow.AttrValue.ListValue', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='s', full_name='tensorflow.AttrValue.ListValue.s', index=0, number=2, type=12, cpp_type=9, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='i', full_name='tensorflow.AttrValue.ListValue.i', index=1, number=3, type=3, cpp_type=2, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=b'\x10\x01', file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='f', full_name='tensorflow.AttrValue.ListValue.f', index=2, number=4, type=2, cpp_type=6, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=b'\x10\x01', file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='b', full_name='tensorflow.AttrValue.ListValue.b', index=3, number=5, type=8, cpp_type=7, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=b'\x10\x01', file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='type', full_name='tensorflow.AttrValue.ListValue.type', index=4, number=6, type=14, cpp_type=8, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=b'\x10\x01', file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='shape', full_name='tensorflow.AttrValue.ListValue.shape', index=5, number=7, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='tensor', full_name='tensorflow.AttrValue.ListValue.tensor', index=6, number=8, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='func', full_name='tensorflow.AttrValue.ListValue.func', index=7, number=9, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=492, serialized_end=725)
_ATTRVALUE = _descriptor.Descriptor(name='AttrValue', full_name='tensorflow.AttrValue', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='s', full_name='tensorflow.AttrValue.s', index=0, number=2, type=12, cpp_type=9, label=1, has_default_value=False, default_value=b'', message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='i', full_name='tensorflow.AttrValue.i', index=1, number=3, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='f', full_name='tensorflow.AttrValue.f', index=2, number=4, type=2, cpp_type=6, label=1, has_default_value=False, default_value=float(0), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='b', full_name='tensorflow.AttrValue.b', index=3, number=5, type=8, cpp_type=7, label=1, has_default_value=False, default_value=False, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='type', full_name='tensorflow.AttrValue.type', index=4, number=6, type=14, cpp_type=8, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='shape', full_name='tensorflow.AttrValue.shape', index=5, number=7, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='tensor', full_name='tensorflow.AttrValue.tensor', index=6, number=8, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='list', full_name='tensorflow.AttrValue.list', index=7, number=1, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='func', full_name='tensorflow.AttrValue.func', index=8, number=10, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='placeholder', full_name='tensorflow.AttrValue.placeholder', index=9, number=9, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[_ATTRVALUE_LISTVALUE], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[_descriptor.OneofDescriptor(name='value', full_name='tensorflow.AttrValue.value', index=0, containing_type=None, create_key=_descriptor._internal_create_key, fields=[])], serialized_start=184, serialized_end=734)
_NAMEATTRLIST_ATTRENTRY = _descriptor.Descriptor(name='AttrEntry', full_name='tensorflow.NameAttrList.AttrEntry', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='key', full_name='tensorflow.NameAttrList.AttrEntry.key', index=0, number=1, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='value', full_name='tensorflow.NameAttrList.AttrEntry.value', index=1, number=2, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=b'8\x01', is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=817, serialized_end=883)
_NAMEATTRLIST = _descriptor.Descriptor(name='NameAttrList', full_name='tensorflow.NameAttrList', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='name', full_name='tensorflow.NameAttrList.name', index=0, number=1, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='attr', full_name='tensorflow.NameAttrList.attr', index=1, number=2, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[_NAMEATTRLIST_ATTRENTRY], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=737, serialized_end=883)
_ATTRVALUE_LISTVALUE.fields_by_name['type'].enum_type = tensorflow_dot_core_dot_framework_dot_types__pb2._DATATYPE
_ATTRVALUE_LISTVALUE.fields_by_name['shape'].message_type = tensorflow_dot_core_dot_framework_dot_tensor__shape__pb2._TENSORSHAPEPROTO
_ATTRVALUE_LISTVALUE.fields_by_name['tensor'].message_type = tensorflow_dot_core_dot_framework_dot_tensor__pb2._TENSORPROTO
_ATTRVALUE_LISTVALUE.fields_by_name['func'].message_type = _NAMEATTRLIST
_ATTRVALUE_LISTVALUE.containing_type = _ATTRVALUE
_ATTRVALUE.fields_by_name['type'].enum_type = tensorflow_dot_core_dot_framework_dot_types__pb2._DATATYPE
_ATTRVALUE.fields_by_name['shape'].message_type = tensorflow_dot_core_dot_framework_dot_tensor__shape__pb2._TENSORSHAPEPROTO
_ATTRVALUE.fields_by_name['tensor'].message_type = tensorflow_dot_core_dot_framework_dot_tensor__pb2._TENSORPROTO
_ATTRVALUE.fields_by_name['list'].message_type = _ATTRVALUE_LISTVALUE
_ATTRVALUE.fields_by_name['func'].message_type = _NAMEATTRLIST
_ATTRVALUE.oneofs_by_name['value'].fields.append(_ATTRVALUE.fields_by_name['s'])
_ATTRVALUE.fields_by_name['s'].containing_oneof = _ATTRVALUE.oneofs_by_name['value']
_ATTRVALUE.oneofs_by_name['value'].fields.append(_ATTRVALUE.fields_by_name['i'])
_ATTRVALUE.fields_by_name['i'].containing_oneof = _ATTRVALUE.oneofs_by_name['value']
_ATTRVALUE.oneofs_by_name['value'].fields.append(_ATTRVALUE.fields_by_name['f'])
_ATTRVALUE.fields_by_name['f'].containing_oneof = _ATTRVALUE.oneofs_by_name['value']
_ATTRVALUE.oneofs_by_name['value'].fields.append(_ATTRVALUE.fields_by_name['b'])
_ATTRVALUE.fields_by_name['b'].containing_oneof = _ATTRVALUE.oneofs_by_name['value']
_ATTRVALUE.oneofs_by_name['value'].fields.append(_ATTRVALUE.fields_by_name['type'])
_ATTRVALUE.fields_by_name['type'].containing_oneof = _ATTRVALUE.oneofs_by_name['value']
_ATTRVALUE.oneofs_by_name['value'].fields.append(_ATTRVALUE.fields_by_name['shape'])
_ATTRVALUE.fields_by_name['shape'].containing_oneof = _ATTRVALUE.oneofs_by_name['value']
_ATTRVALUE.oneofs_by_name['value'].fields.append(_ATTRVALUE.fields_by_name['tensor'])
_ATTRVALUE.fields_by_name['tensor'].containing_oneof = _ATTRVALUE.oneofs_by_name['value']
_ATTRVALUE.oneofs_by_name['value'].fields.append(_ATTRVALUE.fields_by_name['list'])
_ATTRVALUE.fields_by_name['list'].containing_oneof = _ATTRVALUE.oneofs_by_name['value']
_ATTRVALUE.oneofs_by_name['value'].fields.append(_ATTRVALUE.fields_by_name['func'])
_ATTRVALUE.fields_by_name['func'].containing_oneof = _ATTRVALUE.oneofs_by_name['value']
_ATTRVALUE.oneofs_by_name['value'].fields.append(_ATTRVALUE.fields_by_name['placeholder'])
_ATTRVALUE.fields_by_name['placeholder'].containing_oneof = _ATTRVALUE.oneofs_by_name['value']
_NAMEATTRLIST_ATTRENTRY.fields_by_name['value'].message_type = _ATTRVALUE
_NAMEATTRLIST_ATTRENTRY.containing_type = _NAMEATTRLIST
_NAMEATTRLIST.fields_by_name['attr'].message_type = _NAMEATTRLIST_ATTRENTRY
DESCRIPTOR.message_types_by_name['AttrValue'] = _ATTRVALUE
DESCRIPTOR.message_types_by_name['NameAttrList'] = _NAMEATTRLIST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)
AttrValue = _reflection.GeneratedProtocolMessageType('AttrValue', (_message.Message,), {'ListValue': _reflection.GeneratedProtocolMessageType('ListValue', (_message.Message,), {'DESCRIPTOR': _ATTRVALUE_LISTVALUE, '__module__': 'tensorflow.core.framework.attr_value_pb2'}), 'DESCRIPTOR': _ATTRVALUE, '__module__': 'tensorflow.core.framework.attr_value_pb2'})
_sym_db.RegisterMessage(AttrValue)
_sym_db.RegisterMessage(AttrValue.ListValue)
NameAttrList = _reflection.GeneratedProtocolMessageType('NameAttrList', (_message.Message,), {'AttrEntry': _reflection.GeneratedProtocolMessageType('AttrEntry', (_message.Message,), {'DESCRIPTOR': _NAMEATTRLIST_ATTRENTRY, '__module__': 'tensorflow.core.framework.attr_value_pb2'}), 'DESCRIPTOR': _NAMEATTRLIST, '__module__': 'tensorflow.core.framework.attr_value_pb2'})
_sym_db.RegisterMessage(NameAttrList)
_sym_db.RegisterMessage(NameAttrList.AttrEntry)
DESCRIPTOR._options = None
_ATTRVALUE_LISTVALUE.fields_by_name['i']._options = None
_ATTRVALUE_LISTVALUE.fields_by_name['f']._options = None
_ATTRVALUE_LISTVALUE.fields_by_name['b']._options = None
_ATTRVALUE_LISTVALUE.fields_by_name['type']._options = None
_NAMEATTRLIST_ATTRENTRY._options = None



from .pb.tensorflow.core.framework import types_pb2
from . import errors

from typing import Tuple, Optional
import builtins

import numpy as np
try:
  from jaxlib import xla_client as _xc
  _np_bfloat16 = _xc.bfloat16
except ImportError:
  _np_bfloat16 = None

# Standard mappings between types_pb2.DataType values and string names.
_TYPE_TO_STRING = {
  types_pb2.DT_HALF: "float16",
  types_pb2.DT_FLOAT: "float32",
  types_pb2.DT_DOUBLE: "float64",
  types_pb2.DT_INT32: "int32",
  types_pb2.DT_UINT8: "uint8",
  types_pb2.DT_UINT16: "uint16",
  types_pb2.DT_UINT32: "uint32",
  types_pb2.DT_UINT64: "uint64",
  types_pb2.DT_INT16: "int16",
  types_pb2.DT_INT8: "int8",
  types_pb2.DT_STRING: "string",
  types_pb2.DT_COMPLEX64: "complex64",
  types_pb2.DT_COMPLEX128: "complex128",
  types_pb2.DT_INT64: "int64",
  types_pb2.DT_BOOL: "bool",
  types_pb2.DT_QINT8: "qint8",
  types_pb2.DT_QUINT8: "quint8",
  types_pb2.DT_QINT16: "qint16",
  types_pb2.DT_QUINT16: "quint16",
  types_pb2.DT_QINT32: "qint32",
  types_pb2.DT_BFLOAT16: "bfloat16",
  types_pb2.DT_RESOURCE: "resource",
  types_pb2.DT_VARIANT: "variant",
  types_pb2.DT_HALF_REF: "float16_ref",
  types_pb2.DT_FLOAT_REF: "float32_ref",
  types_pb2.DT_DOUBLE_REF: "float64_ref",
  types_pb2.DT_INT32_REF: "int32_ref",
  types_pb2.DT_UINT32_REF: "uint32_ref",
  types_pb2.DT_UINT8_REF: "uint8_ref",
  types_pb2.DT_UINT16_REF: "uint16_ref",
  types_pb2.DT_INT16_REF: "int16_ref",
  types_pb2.DT_INT8_REF: "int8_ref",
  types_pb2.DT_STRING_REF: "string_ref",
  types_pb2.DT_COMPLEX64_REF: "complex64_ref",
  types_pb2.DT_COMPLEX128_REF: "complex128_ref",
  types_pb2.DT_INT64_REF: "int64_ref",
  types_pb2.DT_UINT64_REF: "uint64_ref",
  types_pb2.DT_BOOL_REF: "bool_ref",
  types_pb2.DT_QINT8_REF: "qint8_ref",
  types_pb2.DT_QUINT8_REF: "quint8_ref",
  types_pb2.DT_QINT16_REF: "qint16_ref",
  types_pb2.DT_QUINT16_REF: "quint16_ref",
  types_pb2.DT_QINT32_REF: "qint32_ref",
  types_pb2.DT_BFLOAT16_REF: "bfloat16_ref",
  types_pb2.DT_RESOURCE_REF: "resource_ref",
  types_pb2.DT_VARIANT_REF: "variant_ref",
}
_STRING_TO_TYPE = {
  value: key for key, value in _TYPE_TO_STRING.items()
}
# Add non-canonical aliases.
_STRING_TO_TYPE["half"] = types_pb2.DT_HALF
_STRING_TO_TYPE["half_ref"] = types_pb2.DT_HALF_REF
_STRING_TO_TYPE["float"] = types_pb2.DT_FLOAT
_STRING_TO_TYPE["float_ref"] = types_pb2.DT_FLOAT_REF
_STRING_TO_TYPE["double"] = types_pb2.DT_DOUBLE
_STRING_TO_TYPE["double_ref"] = types_pb2.DT_DOUBLE_REF




# Numpy representation for quantized dtypes.
#
# These are magic strings that are used in the swig wrapper to identify
# quantized types.
# TODO(mrry,keveman): Investigate Numpy type registration to replace this
# hard-coding of names.
_np_qint8 = np.dtype([("qint8", np.int8)])
_np_quint8 = np.dtype([("quint8", np.uint8)])
_np_qint16 = np.dtype([("qint16", np.int16)])
_np_quint16 = np.dtype([("quint16", np.uint16)])
_np_qint32 = np.dtype([("qint32", np.int32)])

# _np_bfloat16 is defined by a module import.

# Custom struct dtype for directly-fed ResourceHandles of supported type(s).
_np_resource = np.dtype([("resource", np.ubyte)])

# Standard mappings between types_pb2.DataType values and numpy.dtypes.
_NP_TO_TYPE = {
  np.float16: types_pb2.DT_HALF,
  np.float32: types_pb2.DT_FLOAT,
  np.float64: types_pb2.DT_DOUBLE,
  np.int32: types_pb2.DT_INT32,
  np.int64: types_pb2.DT_INT64,
  np.uint8: types_pb2.DT_UINT8,
  np.uint16: types_pb2.DT_UINT16,
  np.uint32: types_pb2.DT_UINT32,
  np.uint64: types_pb2.DT_UINT64,
  np.int16: types_pb2.DT_INT16,
  np.int8: types_pb2.DT_INT8,
  np.complex64: types_pb2.DT_COMPLEX64,
  np.complex128: types_pb2.DT_COMPLEX128,
  np.object_: types_pb2.DT_STRING,
  np.string_: types_pb2.DT_STRING,
  np.unicode_: types_pb2.DT_STRING,
  np.bool_: types_pb2.DT_BOOL,
  _np_qint8: types_pb2.DT_QINT8,
  _np_quint8: types_pb2.DT_QUINT8,
  _np_qint16: types_pb2.DT_QINT16,
  _np_quint16: types_pb2.DT_QUINT16,
  _np_qint32: types_pb2.DT_QINT32,
}
if _np_bfloat16 is not None:
  _NP_TO_TYPE[_np_bfloat16] = types_pb2.DT_BFLOAT16


# Map (some) NumPy platform dtypes to TF ones using their fixed-width
# synonyms. Note that platform dtypes are not always simples aliases,
# i.e. reference equality is not guaranteed. See e.g. numpy/numpy#9799.
for pdt in [
  np.intc,
  np.uintc,
  np.int_,
  np.uint,
  np.longlong,
  np.ulonglong,
]:
  if pdt not in _NP_TO_TYPE:
    _NP_TO_TYPE[pdt] = next(
      _NP_TO_TYPE[dt] for dt in _NP_TO_TYPE if dt == pdt().dtype)  # pylint: disable=no-value-for-parameter


TYPE_VALUE_DTYPES = set(_NP_TO_TYPE.values())

_TYPE_TO_NP = {
  types_pb2.DT_HALF:
    np.float16,
  types_pb2.DT_FLOAT:
    np.float32,
  types_pb2.DT_DOUBLE:
    np.float64,
  types_pb2.DT_INT32:
    np.int32,
  types_pb2.DT_UINT8:
    np.uint8,
  types_pb2.DT_UINT16:
    np.uint16,
  types_pb2.DT_UINT32:
    np.uint32,
  types_pb2.DT_UINT64:
    np.uint64,
  types_pb2.DT_INT16:
    np.int16,
  types_pb2.DT_INT8:
    np.int8,
  # NOTE(touts): For strings we use np.object as it supports variable length
  # strings.
  types_pb2.DT_STRING:
    np.object_,
  types_pb2.DT_COMPLEX64:
    np.complex64,
  types_pb2.DT_COMPLEX128:
    np.complex128,
  types_pb2.DT_INT64:
    np.int64,
  types_pb2.DT_BOOL:
    np.bool_,
  types_pb2.DT_QINT8:
    _np_qint8,
  types_pb2.DT_QUINT8:
    _np_quint8,
  types_pb2.DT_QINT16:
    _np_qint16,
  types_pb2.DT_QUINT16:
    _np_quint16,
  types_pb2.DT_QINT32:
    _np_qint32,
  types_pb2.DT_BFLOAT16:
    _np_bfloat16,

  # Ref types
  types_pb2.DT_HALF_REF:
    np.float16,
  types_pb2.DT_FLOAT_REF:
    np.float32,
  types_pb2.DT_DOUBLE_REF:
    np.float64,
  types_pb2.DT_INT32_REF:
    np.int32,
  types_pb2.DT_UINT32_REF:
    np.uint32,
  types_pb2.DT_UINT8_REF:
    np.uint8,
  types_pb2.DT_UINT16_REF:
    np.uint16,
  types_pb2.DT_INT16_REF:
    np.int16,
  types_pb2.DT_INT8_REF:
    np.int8,
  types_pb2.DT_STRING_REF:
    np.object_,
  types_pb2.DT_COMPLEX64_REF:
    np.complex64,
  types_pb2.DT_COMPLEX128_REF:
    np.complex128,
  types_pb2.DT_INT64_REF:
    np.int64,
  types_pb2.DT_UINT64_REF:
    np.uint64,
  types_pb2.DT_BOOL_REF:
    np.bool_,
  types_pb2.DT_QINT8_REF:
    _np_qint8,
  types_pb2.DT_QUINT8_REF:
    _np_quint8,
  types_pb2.DT_QINT16_REF:
    _np_qint16,
  types_pb2.DT_QUINT16_REF:
    _np_quint16,
  types_pb2.DT_QINT32_REF:
    _np_qint32,
  types_pb2.DT_BFLOAT16_REF:
    _np_bfloat16,
}

_PYTHON_TO_TYPE = {
  builtins.float: types_pb2.DT_FLOAT,
  builtins.int: types_pb2.DT_INT32,
  builtins.bool: types_pb2.DT_BOOL,
  builtins.object: types_pb2.DT_STRING,
  builtins.str: types_pb2.DT_STRING,
  builtins.bytes: types_pb2.DT_STRING,
}

def numpy_dtype_to_data_type(dtype) -> Tuple[errors.Status, Optional[int]]:
  dtype = np.dtype(dtype).type
  if dtype in _NP_TO_TYPE:
    return errors.Status.OK(), _NP_TO_TYPE[dtype]
  else:
    return errors.Unimplemented("Can't convert numpy dtype ", dtype, " to data type"), None

def data_type_to_numpy_dtype(type: types_pb2.DataType) -> Tuple[errors.Status, Optional[np.dtype]]:
  if type in _TYPE_TO_NP:
    return errors.Status.OK(), _TYPE_TO_NP[type]
  else:
    return errors.Unimplemented("Can't convert data type ", _TYPE_TO_STRING.get(type, type), " to numpy dtype"), None

# def data_type_to_numpy_dtype_old(type: types_pb2.DataType) -> Tuple[errors.Status, Optional[np.dtype]]:
#   # DT_INVALID = 0
#   # DT_FLOAT = 1
#   # DT_DOUBLE = 2
#   # DT_INT32 = 3
#   # DT_UINT8 = 4
#   # DT_INT16 = 5
#   # DT_INT8 = 6
#   # DT_STRING = 7
#   # DT_COMPLEX64 = 8
#   # DT_INT64 = 9
#   # DT_BOOL = 10
#   # DT_QINT8 = 11
#   # DT_QUINT8 = 12
#   # DT_QINT32 = 13
#   # DT_BFLOAT16 = 14
#   # DT_QINT16 = 15
#   # DT_QUINT16 = 16
#   # DT_UINT16 = 17
#   # DT_COMPLEX128 = 18
#   # DT_HALF = 19
#   # DT_RESOURCE = 20
#   # DT_VARIANT = 21
#   # DT_UINT32 = 22
#   # DT_UINT64 = 23
#   dtype = None
#   if type == types_pb2.DT_FLOAT:
#     dtype = np.float32
#   elif type == types_pb2.DT_DOUBLE:
#     dtype = np.float64
#   elif type == types_pb2.DT_INT32:
#     dtype = np.int32
#   elif type == types_pb2.DT_UINT8:
#     dtype = np.uint8
#   elif type == types_pb2.DT_INT16:
#     dtype = np.int16
#   elif type == types_pb2.DT_INT8:
#     dtype = np.int8
#   elif type == types_pb2.DT_STRING:
#     dtype = np.dtype(bytes)
#   elif type == types_pb2.DT_COMPLEX64:
#     dtype = np.complex64
#   elif type == types_pb2.DT_INT64:
#     dtype = np.int64
#   elif type == types_pb2.DT_BOOL:
#     dtype = np.bool_
#   # elif type == types_pb2.DT_QINT8:
#   #   dtype = np.qint8
#   # elif type == types_pb2.DT_QUINT8:
#   #   dtype = np.quint8
#   # elif type == types_pb2.DT_QINT32:
#   #   dtype = np.qint32
#   elif type == types_pb2.DT_BFLOAT16:
#     if _np_bfloat16 is not None:
#       dtype = _np_bfloat16
#   # elif type == types_pb2.DT_QINT16:
#   #   dtype = np.qint16
#   # elif type == types_pb2.DT_QUINT16:
#   #   dtype = np.quint16
#   elif type == types_pb2.DT_UINT16:
#     dtype = np.uint16
#   elif type == types_pb2.DT_COMPLEX128:
#     dtype = np.complex128
#   elif type == types_pb2.DT_HALF:
#     dtype = np.half
#   # elif type == types_pb2.DT_RESOURCE:
#   #   return errors.Unimplemented("DT_RESOURCE can't be converted to a numpy dtype"), None
#   # elif type == types_pb2.DT_VARIANT:
#   #   return errors.Unimplemented("DT_VARAINT can't be converted to a numpy dtype"), None
#   elif type == types_pb2.DT_UINT32:
#     dtype = np.uint32
#   elif type == types_pb2.DT_UINT64:
#     dtype = np.uint64
#   if dtype is None:
#     return errors.Unimplemented("Can't convert data type ", type, " to numpy dtype"), None
#   return errors.Status.OK(), dtype




'Generated protocol buffer code.'
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
DESCRIPTOR = _descriptor.FileDescriptor(name='tensorflow/core/framework/reader_base.proto', package='tensorflow', syntax='proto3', serialized_options=b'\n\x18org.tensorflow.frameworkB\x10ReaderBaseProtosP\x01ZRgithub.com/tensorflow/tensorflow/tensorflow/go/core/framework/reader_base_go_proto\xf8\x01\x01', create_key=_descriptor._internal_create_key, serialized_pb=b'\n+tensorflow/core/framework/reader_base.proto\x12\ntensorflow"r\n\x0fReaderBaseState\x12\x14\n\x0cwork_started\x18\x01 \x01(\x03\x12\x15\n\rwork_finished\x18\x02 \x01(\x03\x12\x1c\n\x14num_records_produced\x18\x03 \x01(\x03\x12\x14\n\x0ccurrent_work\x18\x04 \x01(\x0cB\x85\x01\n\x18org.tensorflow.frameworkB\x10ReaderBaseProtosP\x01ZRgithub.com/tensorflow/tensorflow/tensorflow/go/core/framework/reader_base_go_proto\xf8\x01\x01b\x06proto3')
_READERBASESTATE = _descriptor.Descriptor(name='ReaderBaseState', full_name='tensorflow.ReaderBaseState', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='work_started', full_name='tensorflow.ReaderBaseState.work_started', index=0, number=1, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='work_finished', full_name='tensorflow.ReaderBaseState.work_finished', index=1, number=2, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='num_records_produced', full_name='tensorflow.ReaderBaseState.num_records_produced', index=2, number=3, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='current_work', full_name='tensorflow.ReaderBaseState.current_work', index=3, number=4, type=12, cpp_type=9, label=1, has_default_value=False, default_value=b'', message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=59, serialized_end=173)
DESCRIPTOR.message_types_by_name['ReaderBaseState'] = _READERBASESTATE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)
ReaderBaseState = _reflection.GeneratedProtocolMessageType('ReaderBaseState', (_message.Message,), {'DESCRIPTOR': _READERBASESTATE, '__module__': 'tensorflow.core.framework.reader_base_pb2'})
_sym_db.RegisterMessage(ReaderBaseState)
DESCRIPTOR._options = None
